@@ -1,6 +1,11 @@
 from .transformer import Transformer
 from .tokenizer import Tokenizer
+from .measurer import Measurer
 from .translator import Translator
+from .vectorizer import Vectorizer
+from .counter import Counter
+from .tfidfer import Tfidfer
+from .searcher import Searcher
 from .variator import Variator
 from .abstractor import Abstractor
 from .questioner import Questioner
